Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Command ¶
type Command int
Command represents a button on the remote
const ( CmdPower Command = 0 CmdSelect Command = 1 CmdBackup Command = 2 CmdDismiss Command = 2 CmdChannelup Command = 6 CmdChanneldown Command = 7 CmdInteractive Command = 8 CmdSidebar Command = 8 CmdHelp Command = 9 CmdServices Command = 10 CmdSearch Command = 10 CmdTvguide Command = 11 CmdHome Command = 11 CmdI Command = 14 CmdText Command = 15 CmdUp Command = 16 CmdDown Command = 17 CmdLeft Command = 18 CmdRight Command = 19 CmdRed Command = 32 CmdGreen Command = 33 CmdYellow Command = 34 CmdBlue Command = 35 Cmd0 Command = 48 Cmd1 Command = 49 Cmd2 Command = 50 Cmd3 Command = 51 Cmd4 Command = 52 Cmd5 Command = 53 Cmd6 Command = 54 Cmd7 Command = 55 Cmd8 Command = 56 Cmd9 Command = 57 CmdPlay Command = 64 CmdPause Command = 65 CmdStop Command = 66 CmdRecord Command = 67 CmdFastforward Command = 69 CmdRewind Command = 71 CmdBoxoffice Command = 240 CmdSky Command = 241 )
Set of commands (buttons) which can be sent
type SkyRemote ¶
SkyRemote allows us to control Sky+HD and SkyQ boxes over IP
func (*SkyRemote) ChangeChannel ¶
ChangeChannel on a Sky box, takes in a string e.g. "115"
func (*SkyRemote) CommandFromDigit ¶
CommandFromDigit returns the correct command from a single digit 0-9
func (*SkyRemote) SendCommand ¶
SendCommand to Sky box
Click to show internal directories.
Click to hide internal directories.